@@ -14,23 +14,12 @@
 from .Surface import Surface, SpectralSurface
 from .Atmosphere import Atmosphere
 
-# from .tm import Tmart
-
 from .Tmart import Tmart
 
-
 from .tm_calcref import calc_ref 
-
 from .tm_geometry import dirP_to_coord
 
-
-
-
-
-
-
-
-
+from tmart import AEC
 
 
 
